Individual Contributors
=======================

A list of people who have contributed to Lookups in order of their first
contribution.

Format: ```Name-or-Well-known-alias <email@domain.tld> (url)```

* Axel Voitier <axel.voitier@gmail.com>

Please, add yourself when you contribute!

Original Netbeans authors of Lookup API
=======================================

* Jaroslav Tulach - Lookup API, AbstractLookup, InstanceContent, ArrayStorage
* Marian Petras - Singleton lookup
* David Strupl - Common lookup implementations
